@@ -15,3 +15,13 @@ test_that("scores by scoring period", {
   )
   expect_equal(length(unique(s$scoringPeriodId)), nrow(s)/4)
 })
+
+test_that("scores by past league history", {
+  s <- tidy_scores(
+    leagueId = "42654852",
+    leagueHistory = TRUE,
+    useMatchup = TRUE
+  )
+  expect_type(s, "list")
+  expect_length(unique(s[[1]]$matchupPeriodId), 17)
+})
